==> rdfjs__parser-jsonld-2.1.2.tgz: rdfjs__parser-jsonld/README.md <==
# Installation
> `npm install --save @types/rdfjs__parser-jsonld`

# Summary
This package contains type definitions for @rdfjs/parser-jsonld (https://github.com/rdfjs-base/parser-jsonld).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/rdfjs__parser-jsonld.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/rdfjs__parser-jsonld/index.d.ts)
````ts
// Type definitions for @rdfjs/parser-jsonld 2.1
// Project: https://github.com/rdfjs-base/parser-jsonld
// Definitions by: Chris Wilkinson <https://github.com/thewilkybarkid>
//                 tpluscode <https://github.com/tpluscode>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped

import { EventEmitter } from "events";
import { Context } from "jsonld/jsonld-spec.js";
import { BaseQuad, DataFactory, Quad, Sink, Stream } from "rdf-js";

export interface ParserOptions {
    baseIRI?: string | undefined;
    context?: Context | undefined;
    factory?: DataFactory | undefined;
}

export default class Parser<Q extends BaseQuad = Quad> implements Sink<EventEmitter, Stream<Q>> {
    constructor(options?: ParserOptions);

    import(stream: EventEmitter, options?: ParserOptions): Stream<Q>;
}

````

### Additional Details
 * Last updated: Wed, 27 Sep 2023 07:12:04 GMT
 * Dependencies: [@types/jsonld](https://npmjs.com/package/@types/jsonld), [@types/rdf-js](https://npmjs.com/package/@types/rdf-js)
 * Global values: none

# Credits
These definitions were written by [Chris Wilkinson](https://github.com/thewilkybarkid), and [tpluscode](https://github.com/tpluscode).

==> rdfjs__parser-jsonld-2.1.3.tgz: rdfjs__parser-jsonld/README.md <==
# Installation
> `npm install --save @types/rdfjs__parser-jsonld`

# Summary
This package contains type definitions for @rdfjs/parser-jsonld (https://github.com/rdfjs-base/parser-jsonld).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/rdfjs__parser-jsonld.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/rdfjs__parser-jsonld/index.d.ts)
````ts
// Type definitions for @rdfjs/parser-jsonld 2.1
// Project: https://github.com/rdfjs-base/parser-jsonld
// Definitions by: Chris Wilkinson <https://github.com/thewilkybarkid>
//                 tpluscode <https://github.com/tpluscode>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped

import { EventEmitter } from "events";
import { Context } from "jsonld/jsonld-spec.js";
import { BaseQuad, DataFactory, Quad, Sink, Stream } from "rdf-js";

export interface ParserOptions {
    baseIRI?: string | undefined;
    context?: Context | undefined;
    factory?: DataFactory | undefined;
}

export default class Parser<Q extends BaseQuad = Quad> implements Sink<EventEmitter, Stream<Q>> {
    constructor(options?: ParserOptions);

    import(stream: EventEmitter, options?: ParserOptions): Stream<Q>;
}

````

### Additional Details
 * Last updated: Tue, 10 Oct 2023 18:07:32 GMT
 * Dependencies: [@types/jsonld](https://npmjs.com/package/@types/jsonld), [@types/rdf-js](https://npmjs.com/package/@types/rdf-js)
 * Global values: none

# Credits
These definitions were written by [Chris Wilkinson](https://github.com/thewilkybarkid), and [tpluscode](https://github.com/tpluscode).
